@@ -180,7 +180,7 @@ def msa(og, program='clustalw'):
     return og
 
 
-def tree(og, program='fasttree'):
+def tree(og, program='fasttree', bs=1000):
     og.tree_file = og.work_dir+"/tree.phb"
 
     if program == 'fasttree':
@@ -191,12 +191,26 @@ def tree(og, program='fasttree'):
         cmd_string = "raxml-ng --msa %s --model LG+G4 --seed 12345 --threads 1" % og.aa_aln
         cmd_run(cmd_string, silence=True)
         output_filename = og.aa_aln + ".raxml.bestTree"
-        move_file(output_filename, og.tree_file)
+        if have_file(output_filename):
+            move_file(output_filename, og.tree_file)
+        else:
+            og.tree_file = None
     elif program == 'raxml_support':
-        cmd_string = "raxml-ng --msa %s --model LG+G4 --seed 12345 --threads 1 --all --bs-trees 100" % og.aa_aln
+        cmd_string = "raxml-ng --msa %s --model LG+G4 --seed 12345 --threads 1 --all --bs-trees %d" % (og.aa_aln, bs)
         cmd_run(cmd_string, silence=True)
         output_filename = og.aa_aln + ".raxml.support"
-        move_file(output_filename, og.tree_file)
+        if have_file(output_filename):
+            move_file(output_filename, og.tree_file)
+        else:
+            og.tree_file = None
+    elif program == 'iqtree':
+        cmd_string = "iqtree -s %s -bb %d" % (og.aa_aln, bs)
+        cmd_run(cmd_string, silence=True)
+        output_filename = og.aa_aln + ".contree"
+        if have_file(output_filename):
+            move_file(output_filename, og.tree_file)
+        else:
+            og.tree_file = None
 
     return og
 
@@ -206,41 +220,25 @@ def root_tree(og):
                                    'new_id', 'old_id', 'speci'], key_col='new_id')
     gene_to_species_map_dict = {i: tmp_info[i]["speci"] for i in tmp_info}
 
-    og.rooted_tree = og.work_dir+"/tree.rooted.phb"
-    get_root_by_species_for_file(
-        og.tree_file, og.species_tree_file, gene_to_species_map_dict, og.rooted_tree)
+    if og.tree_file:
+        og.rooted_tree = og.work_dir+"/tree.rooted.phb"
+        get_root_by_species_for_file(
+            og.tree_file, og.species_tree_file, gene_to_species_map_dict, og.rooted_tree)
+    else:
+        og.rooted_tree = None
 
     return og
 
 
 def resolve_tree(og, program='auto'):
-    og.resolve_tree = og.work_dir+"/tree.resolve.phb"
-    tmp_info = tsv_file_dict_parse(og.rename_map, fieldnames=[
-        'new_id', 'old_id', 'speci'], key_col='new_id')
-    gene_to_species_map_dict = {i: tmp_info[i]["speci"] for i in tmp_info}
+    if og.rooted_tree:
+        og.resolve_tree = og.work_dir+"/tree.resolve.phb"
+        tmp_info = tsv_file_dict_parse(og.rename_map, fieldnames=[
+            'new_id', 'old_id', 'speci'], key_col='new_id')
+        gene_to_species_map_dict = {i: tmp_info[i]["speci"] for i in tmp_info}
 
-    if program == 'dlcpar':
+        if program == 'dlcpar':
 
-        dlcpar_name_map_file = og.work_dir+"/dlcpar.name.map"
-        with open(dlcpar_name_map_file, 'w') as f:
-            for i in tmp_info:
-                f.write("%s\t%s\n" % (i, tmp_info[i]["speci"]))
-
-        recon_tree_file, recon_node_file = run_dlcpar(
-            og.species_tree_file, dlcpar_name_map_file, og.rooted_tree)
-
-        move_file(recon_tree_file, og.resolve_tree)
-
-    elif program == 'orthofinder':
-        gene_tree = Phylo.read(og.rooted_tree, 'newick')
-
-        resolve_gene_tree = resolve_rooted_gene_tree(
-            gene_tree, gene_to_species_map_dict)
-        with open(og.resolve_tree, 'w') as f:
-            Phylo.write(resolve_gene_tree, f, 'newick')
-
-    elif program == 'auto':
-        try:
             dlcpar_name_map_file = og.work_dir+"/dlcpar.name.map"
             with open(dlcpar_name_map_file, 'w') as f:
                 for i in tmp_info:
@@ -251,7 +249,7 @@ def resolve_tree(og, program='auto'):
 
             move_file(recon_tree_file, og.resolve_tree)
 
-        except:
+        elif program == 'orthofinder':
             gene_tree = Phylo.read(og.rooted_tree, 'newick')
 
             resolve_gene_tree = resolve_rooted_gene_tree(
@@ -259,18 +257,45 @@ def resolve_tree(og, program='auto'):
             with open(og.resolve_tree, 'w') as f:
                 Phylo.write(resolve_gene_tree, f, 'newick')
 
+        elif program == 'auto':
+            try:
+                dlcpar_name_map_file = og.work_dir+"/dlcpar.name.map"
+                with open(dlcpar_name_map_file, 'w') as f:
+                    for i in tmp_info:
+                        f.write("%s\t%s\n" % (i, tmp_info[i]["speci"]))
+
+                recon_tree_file, recon_node_file = run_dlcpar(
+                    og.species_tree_file, dlcpar_name_map_file, og.rooted_tree)
+
+                move_file(recon_tree_file, og.resolve_tree)
+
+            except:
+                gene_tree = Phylo.read(og.rooted_tree, 'newick')
+
+                resolve_gene_tree = resolve_rooted_gene_tree(
+                    gene_tree, gene_to_species_map_dict)
+                with open(og.resolve_tree, 'w') as f:
+                    Phylo.write(resolve_gene_tree, f, 'newick')
+    else:
+        og.resolve_tree = None
+
     return og
 
 
 def tree_map_taxon_info(og, use_reslove_tree=True):
+
     tmp_info = tsv_file_dict_parse(og.rename_map, fieldnames=[
         'new_id', 'old_id', 'speci'], key_col='new_id')
     gene_to_species_map_dict = {i: tmp_info[i]["speci"] for i in tmp_info}
 
-    if use_reslove_tree:
+    if use_reslove_tree and og.resolve_tree:
         resolve_tree = Phylo.read(og.resolve_tree, 'newick')
-    else:
+    elif use_reslove_tree is False and og.rooted_tree:
         resolve_tree = Phylo.read(og.rooted_tree, 'newick')
+    else:
+        og.nhx_file = None
+        return og
+        
     species_tree = Phylo.read(og.species_tree_file, 'newick')
 
     og.nhx_file = og.work_dir+"/tree.nhx"
