@@ -1,8 +1,8 @@
-from lib.common.evolution.tree_operate import get_sons
+from toolbiox.lib.common.evolution.tree_operate import get_sons
 from Bio import Phylo
-from config import badirate_path
-from lib.common.os import mkdir, rmdir, cmd_run, multiprocess_running
-from lib.common.util import logging_init
+from toolbiox.config import badirate_path
+from toolbiox.lib.common.os import mkdir, rmdir, cmd_run, multiprocess_running
+from toolbiox.lib.common.util import logging_init
 import copy
 import os
 import re
