@@ -2,12 +2,12 @@
 import pysam
 import time
 import copy
-from lib.common.os import remove_file_name_suffix, cmd_run, multiprocess_running
-from lib.xuyuxing.base.common_command import flag_maker, flag_parse, flag_filter
-from lib.common.util import logging_init
-from lib.common.genome.seq_base import read_fastq_big, read_fasta_by_faidx
+from toolbiox.lib.common.os import remove_file_name_suffix, cmd_run, multiprocess_running
+from toolbiox.lib.xuyuxing.base.common_command import flag_maker, flag_parse, flag_filter
+from toolbiox.lib.common.util import logging_init
+from toolbiox.lib.common.genome.seq_base import read_fastq_big, read_fasta_by_faidx
 from pysam import VariantFile
-from lib.common.math.bin_and_window import split_sequence_to_bins
+from toolbiox.lib.common.math.bin_and_window import split_sequence_to_bins
 import pickle
 import numpy as np
 
@@ -638,7 +638,7 @@ if __name__ == "__main__":
             return True_flag
 
 
-    from lib.xuyuxing.math.stats import fisher_enrichment
+    from toolbiox.lib.xuyuxing.math.stats import fisher_enrichment
 
     def heterozygote_pvalue(AD_dict, ratio_dict):
         """
@@ -689,7 +689,7 @@ if __name__ == "__main__":
 
     gff_file = '/lustre/home/xuyuxing/Work/Other/Guojin/tomato_collinear/genome_data/Sly/ITAG4.1_gene_models.gff'
 
-    from lib.common.genome.genome_feature2 import read_gff_file
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
 
     gf_dict = read_gff_file(gff_file)
     gene_dict = gf_dict['gene']
@@ -799,7 +799,7 @@ if __name__ == "__main__":
 
     gff_file = '/lustre/home/xuyuxing/Work/Other/Guojin/tomato_collinear/genome_data/Sly/ITAG4.1_gene_models.gff'
 
-    from lib.common.genome.genome_feature2 import read_gff_file
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
 
     gf_dict = read_gff_file(gff_file)
     gene_dict = gf_dict['gene']
