@@ -1,17 +1,98 @@
-import numpy as np
-from matplotlib import cm, rc, rcParams
-import matplotlib.pyplot as plt
-import matplotlib as mpl
-from matplotlib.lines import Line2D
 from matplotlib.path import Path
-import matplotlib.patches as Patches
-
 from toolbiox.lib.xuyuxing.base.console import green, dark
-import copy
-import os.path as op
-import sys
-import logging
 import matplotlib.cbook as cbook
+import matplotlib.patches as Patches
+import matplotlib.pyplot as plt
+import matplotlib.transforms as mtransforms
+import numpy as np
+import sys
+
+
+class STICK_PLOT():
+    def get_patch(self, start_point, end_point, ax, thickness=2, linewidth=2, alpha=1, facecolor='b', edgecolor='k', bulge=0.67):
+
+        x1, y1 = start_point
+        x2, y2 = end_point
+
+        l = np.sqrt(np.square(x1-x2) + np.square(y1-y2))
+
+        # 0-base
+        p1 = 0, thickness/2
+        p2 = l, thickness/2
+        p3 = l+thickness*bulge, thickness/2
+        p4 = l+thickness*bulge, -thickness/2
+        p5 = l, -thickness/2
+        p6 = 0, -thickness/2
+        p7 = 0-thickness*bulge, -thickness/2
+        p8 = 0-thickness*bulge, thickness/2
+
+        # transforms
+        deg = self.get_rotate_deg(y2-y1, x2-x1)
+        trans = (x1, y1)
+
+        tp1 = self.get_transforms_point(p1, deg, trans, ax)
+        tp2 = self.get_transforms_point(p2, deg, trans, ax)
+        tp3 = self.get_transforms_point(p3, deg, trans, ax)
+        tp4 = self.get_transforms_point(p4, deg, trans, ax)
+        tp5 = self.get_transforms_point(p5, deg, trans, ax)
+        tp6 = self.get_transforms_point(p6, deg, trans, ax)
+        tp7 = self.get_transforms_point(p7, deg, trans, ax)
+        tp8 = self.get_transforms_point(p8, deg, trans, ax)
+
+        patch = self.stick_base(tp1, tp2, tp3, tp4, tp5, tp6, tp7, tp8, linewidth=linewidth,
+                                alpha=alpha, facecolor=facecolor, edgecolor=edgecolor)
+
+        return patch
+
+    def get_rotate_deg(self, o, a):
+        """
+        opposite:对边
+        adjacent:临边
+        """
+        if a == 0 and o > 0:
+            return 90
+        elif a == 0 and o < 0:
+            return -90
+        elif o == 0 and a > 0:
+            return 0
+        elif o == 0 and a < 0:
+            return 180
+        else:
+            return np.arctan(o/a)/np.pi*180
+
+    def reget_ax_point(self, point, transData, ax):
+        inv = ax.transData.inverted()
+        return inv.transform(transData.transform(point))
+
+    def get_transforms_point(self, x, deg, trans, ax):
+        affline = mtransforms.Affine2D().rotate_deg_around(0, 0, deg).translate(*trans)
+        transData = affline + ax.transData
+        return self.reget_ax_point(x, transData, ax)
+
+    def stick_base(self, p1, p2, p3, p4, p5, p6, p7, p8, linewidth=2, alpha=0.5, facecolor='b', edgecolor='k'):
+        path_data = [
+            # up line
+            (Path.MOVETO, p1),
+            (Path.LINETO, p2),
+            # right CURVE4
+            (Path.CURVE4, p3),
+            (Path.CURVE4, p4),
+            (Path.CURVE4, p5),
+            # down line
+            (Path.LINETO, p6),
+            # left CURVE4
+            (Path.CURVE4, p7),
+            (Path.CURVE4, p8),
+            (Path.CURVE4, p1),
+        ]
+
+        codes, verts = zip(*path_data)
+        path = Path(verts, codes)
+
+        patch = Patches.PathPatch(
+            path, alpha=alpha, facecolor=facecolor, edgecolor=edgecolor, linewidth=linewidth)
+
+        return patch
 
 
 def save_figure(fig_object, output_file, format='svg'):
@@ -110,7 +191,7 @@ def asciiplot(x, y, digit=1, width=50, title=None, char="="):
         print("{0} |{1} {2}".format(x, z, y), file=sys.stderr)
 
 
-# litter plot
+# little plot
 def add_stick_box_plot(start, end, high=5, x_y_lim=None, thickness=2, linewidth=2, alpha=0.5, facecolor='b', edgecolor='k', bulge=2):
     if not x_y_lim:
         circle_radius = thickness/bulge
@@ -168,3 +249,15 @@ def add_small_axes_on_other(main_ax, figure, left_bottom_xy, right_top_xy):
         main_ax.transData.transform(right_top_xy))
 
     return figure.add_axes([lb_xy[0], lb_xy[1], rt_xy[0]-lb_xy[0], rt_xy[1]-lb_xy[1]])
+
+
+if __name__ == "__main__":
+    # stick plot
+    fig, ax = plt.subplots(figsize=(10, 10))
+    stick_plot = STICK_PLOT()
+
+    patch = stick_plot.get_patch(
+        (0, 1.5), (1, 1.5), ax, thickness=0.1, linewidth=0, facecolor='b')
+    ax.add_patch(patch)
+
+    plt.show()
