@@ -552,6 +552,18 @@ def remove_pass_node(tree):
     return new_tree
 
 
+def make_unique_name(tree):
+    tree_new = copy.deepcopy(tree)
+    names = {}
+    for clade in tree_new.find_clades():
+        if clade.name:
+            if clade.name in names:
+                names[clade.name].append(clade.name)
+                clade.name = "%s.%d" % (clade.name, len(names[clade.name]))
+            names[clade.name] = [clade.name]
+    return tree_new
+
+
 def mid_unrooted_tree(tree):
     """
     root a unrooted tree at midpoint
@@ -1731,5 +1743,3 @@ _|                |________________|S2:
     from Bio.SeqIO import parse
 
     #
-
-    
\ No newline at end of file
