@@ -321,7 +321,7 @@ def genome_cover_plot(plot_chr_id_list, chr_length_dict, base_cover_chr_dict, ba
 # dotplot + cover plot
 
 
-def add_contig_grid(ax, query_contig_length_dict, subject_contig_length_dict, q_top=None, s_top=None, grid_colors='k', linewidths=0.5, q_contig_list=None, s_contig_list=None):
+def add_contig_grid(ax, query_contig_length_dict, subject_contig_length_dict, q_top=None, s_top=None, grid_colors='k', linewidths=0.5, q_contig_list=None, s_contig_list=None, rename_chr_map=None):
     query_contig_coord = {}
     subject_contig_coord = {}
 
@@ -345,7 +345,10 @@ def add_contig_grid(ax, query_contig_length_dict, subject_contig_length_dict, q_
         q_num += query_contig_length_dict[i]
         q_hline_y_site.append(q_num)
         q_tick_local.append(q_num - query_contig_length_dict[i]/2)
-        q_tick_label.append(i)
+        if rename_chr_map:
+            q_tick_label.append(rename_chr_map[i])
+        else:
+            q_tick_label.append(i)
 
     q_hline_y_site = q_hline_y_site[:-1]
 
@@ -372,7 +375,10 @@ def add_contig_grid(ax, query_contig_length_dict, subject_contig_length_dict, q_
         s_num += subject_contig_length_dict[i]
         s_vline_y_site.append(s_num)
         s_tick_local.append(s_num - subject_contig_length_dict[i]/2)
-        s_tick_label.append(i)
+        if rename_chr_map:
+            s_tick_label.append(rename_chr_map[i])
+        else:
+            s_tick_label.append(i)
 
     s_vline_y_site = s_vline_y_site[:-1]
 
