@@ -10,11 +10,11 @@ from BCBio import GFF
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from Bio.SeqFeature import SeqFeature, FeatureLocation
-from lib.common.math.interval import merge_intervals, interval_minus_set
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.os import cmd_run
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.util import printer_list
+from toolbiox.lib.common.math.interval import merge_intervals, interval_minus_set
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.lib.common.os import cmd_run
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.util import printer_list
 
 # tools for seq as string
 
@@ -1339,7 +1339,7 @@ class SyntenyBlock(object):
 
 
 if __name__ == '__main__':
-    from config import project_dir
+    from toolbiox.config import project_dir
 
     Ath_genome_fasta_file = project_dir + \
         "/example_dataset/genome/Ath/T3702N0.genome.fasta"
