@@ -1,12 +1,12 @@
-from api.xuyuxing.comp_genome.planttribes import seq_classify
+from toolbiox.api.xuyuxing.comp_genome.planttribes import seq_classify
 from BCBio import GFF
 from interlap import InterLap
-from lib.common.evolution.orthotools2 import OrthoGroups, OrthoGroup
-from lib.common.genome.genome_feature2 import Gene, HomoPredictResults
-from lib.common.math.interval import overlap_between_interval_set, group_by_intervals_with_overlap_threshold, sum_interval_length
-from lib.common.os import mkdir, multiprocess_running
-from lib.common.util import logging_init, configure_parser
-from src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
+from toolbiox.lib.common.evolution.orthotools2 import OrthoGroups, OrthoGroup
+from toolbiox.lib.common.genome.genome_feature2 import Gene, HomoPredictResults
+from toolbiox.lib.common.math.interval import overlap_between_interval_set, group_by_intervals_with_overlap_threshold, sum_interval_length
+from toolbiox.lib.common.os import mkdir, multiprocess_running
+from toolbiox.lib.common.util import logging_init, configure_parser
+from toolbiox.src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
 import configparser
 import os
 import pickle
