@@ -1,11 +1,11 @@
 import pysam
 import os
-from lib.base.base_function import cmd_run
+from toolbiox.lib.base.base_function import cmd_run
 import time 
-from lib.seq.seq_base import read_fastq_big
+from toolbiox.lib.seq.seq_base import read_fastq_big
 import sys
-import lib.file_parser.sqlite_command as sc
-from lib.file_parser.fileIO import read_list_file
+import toolbiox.lib.file_parser.sqlite_command as sc
+from toolbiox.lib.file_parser.fileIO import read_list_file
 
 __author__ = 'Yuxing Xu'
 
